package cn.iocoder.yudao.module.shipment.dal.mysql;

import java.util.*;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.query.LambdaQuery;
import cn.iocoder.yudao.framework.mybatis.core.mapper.AbstractMapper;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.dal.dataobject.approval.OrderApprovalDO;
import cn.iocoder.yudao.module.shipment.dal.dataobject.BoxApprovalDO;
import cn.iocoder.yudao.module.shipment.vo.boxApproval.BoxApprovalQueryVO;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.ResultType;
import org.apache.ibatis.annotations.Select;

/**
 * 出货审核 Mapper
 * @author wlh
 */
@Mapper
public interface BoxApprovalMapper extends AbstractMapper<BoxApprovalDO> {
    @Override
    default PageResult<BoxApprovalDO> selectPage(PageVO page, Object object) {
        if (object instanceof BoxApprovalQueryVO) {
            BoxApprovalQueryVO vo = (BoxApprovalQueryVO)object;
            return selectPage(page, new LambdaQuery<BoxApprovalDO>()
                .eqIfPresent(BoxApprovalDO::getShipmentId, vo.getShipmentId())
                .eqIfPresent(BoxApprovalDO::getApprovalType, vo.getApprovalType())
                .eqIfPresent(BoxApprovalDO::getApprovalStatus, vo.getApprovalStatus())
                .betweenIfPresent(BoxApprovalDO::getCreateTime, vo.getBeginCreateTime(), vo.getEndCreateTime())
                    .orderByDesc(BoxApprovalDO::getId));
        }

        return null;
    }

    @Override
    default List<BoxApprovalDO> selectList(Object object) {
        if (object instanceof BoxApprovalQueryVO) {
            BoxApprovalQueryVO vo = (BoxApprovalQueryVO)object;
            return selectList(new LambdaQuery<BoxApprovalDO>()
                .eqIfPresent(BoxApprovalDO::getShipmentId, vo.getShipmentId())
                .eqIfPresent(BoxApprovalDO::getApprovalType, vo.getApprovalType())
                .eqIfPresent(BoxApprovalDO::getApprovalStatus, vo.getApprovalStatus())
                .betweenIfPresent(BoxApprovalDO::getCreateTime, vo.getBeginCreateTime(), vo.getEndCreateTime())
                    .orderByDesc(BoxApprovalDO::getId));
        }

        return null;
    }

    @ResultType(BoxApprovalDO.class)
    @Select({
            "<script>",
            "select",
            " a.* ",
            "from ecw_box_approval a",
            "where ",
            "a.shipment_id = #{shipmentId}",
            "and (a.order_id is null or (a.order_id is not null and a.order_id = #{orderId}) )",
            "order by a.id desc",
            "</script>"
    })
    List<BoxApprovalDO> checkOrderProcessingApproval(@Param("shipmentId") Long shipmentId, @Param("orderId") Long orderId);
}
